import Vue from 'vue'

import 'normalize.css/normalize.css' // A modern alternative to CSS resets

import ElementUI from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'
import locale from 'element-ui/lib/locale/lang/en' // lang i18n

import '@/styles/index.scss' // global css

import App from './App'
import store from './store'
import router from './router'

import '@/icons' // icon
import '@/permission' // permission control

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online ! ! !
 */
if (process.env.NODE_ENV === 'production') {
  const { mockXHR } = require('../mock')
  mockXHR()
}

// set ElementUI lang to EN
// Vue.use(ElementUI, { locale })
// 如果想要中文版 element-ui，按如下方式声明
Vue.use(ElementUI)

import API from '@/api'
Vue.prototype.$API = API

// 全局组件 分页器
import Pagination from '@/components/Pagination/Pagination'
Vue.component('Pagination', Pagination)
// 封装一个message
Vue.prototype.message = function(type = 'warning', message) {
  return this.$message({
    message: message,
    type
  });
}
// 在 main.js 中注册全局过滤器
Vue.filter('formatDate', function(value) {
  if (!value) return '';
  
  // 解析日期
  const date = new Date(value);

  // 检查日期是否有效
  if (isNaN(date)) return '';

  // 格式化日期为 yyyy-MM-dd HH:mm:ss
  return date.getFullYear() + '-' + 
         (date.getMonth() + 1).toString().padStart(2, '0') + '-' + 
         date.getDate().toString().padStart(2, '0') + ' ' + 
         date.getHours().toString().padStart(2, '0') + ':' + 
         date.getMinutes().toString().padStart(2, '0') + ':' + 
         date.getSeconds().toString().padStart(2, '0');
});


Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  beforeCreate() {
    Vue.prototype.$bus = this
  },
  render: h => h(App)
})
